2025-02-27  Emil Viesná  <snowboard_refinery@proton.me>

	v1.0.2 [py3.12]

	* tests/test.sh: added.

2024-10-07  Emil Viesná  <snowboard_refinery@proton.me>

	Optimization

	* src/muppy/main.py: UUIDs replaced by simple incremental numbers
	* README.md: HTML example is edited according to changes

2024-10-07  Emil Viesná  <snowboard_refinery@proton.me>

	v1.0.1

	* src/muppy/main.py: Fixed definitions NoneType bug

2024-10-07  Emil Viesná  <snowboard_refinery@proton.me>

	v1.0.0

	* src/muppy/main.py: Rough search of XML-, TeX-, C-, and Shell-styled
	comments.
